# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_specific_stats import AgentConnectorSpecificStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorSpecificStats(unittest.TestCase):
    """AgentConnectorSpecificStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorSpecificStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_specific_stats.AgentConnectorSpecificStats()  # noqa: E501
        if include_optional :
            return AgentConnectorSpecificStats(
                system = agilicus_api.models.agent_connector_system_stats.AgentConnectorSystemStats(
                    os_version = 'Linux 5.4.0-45-generic #49-Ubuntu SMP Wed Aug 26 13:38:52 UTC 2020 x86_64 GNU/Linux', 
                    os_uptime = 45232, 
                    agent_uptime = 45000, 
                    agent_version = 'v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259', 
                    agent_release_train = 'stable', 
                    agent_connector_id = 'SdaAs93adflq3a', 
                    agent_connector_org_id = 'd0d4laSDr4ws9', ), 
                transport = agilicus_api.models.agent_connector_transport_stats.AgentConnectorTransportStats(
                    active_connections = 32, 
                    target_number_connections = 32, 
                    connection_start_count = 64, 
                    connection_stop_count = 32, ), 
                shares = agilicus_api.models.agent_connector_share_stats.AgentConnectorShareStats(
                    exposed_shares_count = 2, 
                    server_running = True, 
                    server_start_time = '2020-07-07T15:55:51.230Z', 
                    server_stop_time = '2020-07-07T15:55:51.230Z', 
                    server_start_count = 2, 
                    server_stop_count = 1, 
                    per_share_info = [
                        agilicus_api.models.agent_connector_per_share_stats.AgentConnectorPerShareStats(
                            share_prefix = '/public', 
                            share_id = '5s930sdfsdlA', 
                            local_path = '/home/user/shared', 
                            total_requests = 5132, 
                            successful_requests = 5102, 
                            failed_requests = 30, 
                            bytes_sent = 30458101, 
                            bytes_received = 9574339, 
                            share_start_time = '2020-07-07T15:55:52.230Z', )
                        ], ), 
                authz = agilicus_api.models.agent_connector_authz_stats.AgentConnectorAuthzStats(
                    allowed = 32, 
                    allowed_app_handled = 32, 
                    denied = 32, 
                    token_cached_failed = 64, 
                    token_cached_success = 64, 
                    token_parse_failed = 64, 
                    token_static_token = 64, 
                    token_bad_jti = 64, 
                    token_lookup_success = 64, 
                    token_lookup_notfound = 64, 
                    token_lookup_badrequest = 64, 
                    token_lookup_4xx_other = 64, 
                    token_lookup_error = 64, 
                    token_lookup_revoked = 64, 
                    token_basic_auth_decode_fail = 64, 
                    token_basic_auth_too_long = 64, 
                    token_basic_auth_no_password = 64, 
                    token_basic_auth_cached_success = 64, 
                    token_basic_auth_cached_failed = 64, ), 
                proxy = agilicus_api.models.agent_connector_proxy_stats.AgentConnectorProxyStats(
                    overview = agilicus_api.models.agent_connector_proxy_request_stats.AgentConnectorProxyRequestStats(
                        last_request_start_time = '2020-07-07T15:49:51.230Z', 
                        bytes_received = 0, 
                        bytes_sent = 0, 
                        requests = agilicus_api.models.agent_connector_proxy_request_stats_details.AgentConnectorProxyRequestStatsDetails(
                            started = 0, 
                            finished = 0, 
                            status_1xx = 0, 
                            status_2xx = 0, 
                            status_3xx = 0, 
                            status_4xx = 0, 
                            status_5xx = 0, 
                            status_unknown = 0, 
                            failed_authentication = 0, 
                            failed_authorisation = 0, ), ), 
                    start_time = '2020-07-07T15:49:51.230Z', 
                    stop_time = '2020-07-07T15:49:51.230Z', )
            )
        else :
            return AgentConnectorSpecificStats(
                system = agilicus_api.models.agent_connector_system_stats.AgentConnectorSystemStats(
                    os_version = 'Linux 5.4.0-45-generic #49-Ubuntu SMP Wed Aug 26 13:38:52 UTC 2020 x86_64 GNU/Linux', 
                    os_uptime = 45232, 
                    agent_uptime = 45000, 
                    agent_version = 'v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259', 
                    agent_release_train = 'stable', 
                    agent_connector_id = 'SdaAs93adflq3a', 
                    agent_connector_org_id = 'd0d4laSDr4ws9', ),
                transport = agilicus_api.models.agent_connector_transport_stats.AgentConnectorTransportStats(
                    active_connections = 32, 
                    target_number_connections = 32, 
                    connection_start_count = 64, 
                    connection_stop_count = 32, ),
        )

    def testAgentConnectorSpecificStats(self):
        """Test AgentConnectorSpecificStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.host_permissions import HostPermissions  # noqa: E501
from agilicus_api.rest import ApiException

class TestHostPermissions(unittest.TestCase):
    """HostPermissions unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test HostPermissions
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.host_permissions.HostPermissions()  # noqa: E501
        if include_optional :
            return HostPermissions(
                upstream_host = '0', 
                app_id = '123', 
                admin_org_id = '123', 
                allowed_list = [
                    agilicus_api.models.rendered_rule.RenderedRule(
                        methods = [
                            'get'
                            ], 
                        paths = [
                            '0'
                            ], 
                        query_parameters = [
                            agilicus_api.models.rendered_query_parameter.RenderedQueryParameter(
                                name = '0', 
                                exact_match = '0', )
                            ], 
                        body = agilicus_api.models.rendered_rule_body.RenderedRuleBody(
                            json = [
                                agilicus_api.models.json_body_constraint.JSONBodyConstraint(
                                    name = '0', 
                                    exact_match = '0', 
                                    match_type = 'string', 
                                    pointer = '/foo/0/a~1b/2', )
                                ], ), )
                    ]
            )
        else :
            return HostPermissions(
        )

    def testHostPermissions(self):
        """Test HostPermissions"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.oidc_upstream_identity_provider import OIDCUpstreamIdentityProvider  # noqa: E501
from agilicus_api.rest import ApiException

class TestOIDCUpstreamIdentityProvider(unittest.TestCase):
    """OIDCUpstreamIdentityProvider unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OIDCUpstreamIdentityProvider
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.oidc_upstream_identity_provider.OIDCUpstreamIdentityProvider()  # noqa: E501
        if include_optional :
            return OIDCUpstreamIdentityProvider(
                name = '0', 
                icon = 'city-login', 
                issuer = '0', 
                client_id = '0', 
                client_secret = '0', 
                issuer_external_host = '0', 
                username_key = '0', 
                email_key = '0', 
                email_verification_required = True, 
                request_user_info = True, 
                user_id_key = '0', 
                auto_create_status = 'active'
            )
        else :
            return OIDCUpstreamIdentityProvider(
                name = '0',
                issuer = '0',
                client_id = '0',
        )

    def testOIDCUpstreamIdentityProvider(self):
        """Test OIDCUpstreamIdentityProvider"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from . import context
from .input_helpers import get_org_from_input_or_ctx
import agilicus
from .output.table import (
    spec_column,
    format_table,
    metadata_column,
    status_column,
    subtable,
)


def add_agent_csr(ctx, connector_id, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs.pop("org_id", None)

    if kwargs["request"] is not None:
        csr_request = open(kwargs["request"], "r").read()
        kwargs["request"] = csr_request

    spec = agilicus.CertSigningReqSpec(org_id=org_id, **kwargs)
    req = agilicus.CertSigningReq(spec=spec)
    return apiclient.connectors_api.create_agent_csr(connector_id, req)


def list_agent_csr(ctx, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs.pop("org_id", None)

    query_results = apiclient.connectors_api.list_agent_csr(
        org_id=org_id, **kwargs
    ).certificate_signing_requests
    return query_results


def get_agent_csr(ctx, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs.pop("org_id", None)

    return apiclient.connectors_api.get_agent_csr(
        org_id=org_id,
        **kwargs,
    )


def list_csr(ctx, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs.pop("org_id", None)

    query_results = apiclient.certificates_api.list_csr(
        org_id=org_id, **kwargs
    ).certificate_signing_requests
    return query_results


def get_csr(ctx, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs.pop("org_id", None)

    return apiclient.certificates_api.get_csr(org_id=org_id, **kwargs)


def delete_csr(ctx, **kwargs):
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    org_id = get_org_from_input_or_ctx(ctx, **kwargs)
    kwargs.pop("org_id", None)

    return apiclient.certificates_api.delete_csr(org_id=org_id, **kwargs)


def format_csr_as_text(ctx, csrs):
    certificate_columns = [
        spec_column("message"),
        spec_column("reason"),
    ]
    columns = [
        metadata_column("id"),
        spec_column("org_id"),
        status_column("common_name"),
        status_column("dns_names"),
        subtable(ctx, "certificates", certificate_columns, subobject_name="status"),
    ]

    return format_table(ctx, csrs, columns)



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class MFAChallengeQuestionLoginInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_preference': 'str',
        'client_id': 'str',
        'client_guid': 'str',
        'issuer_org_id': 'str',
        'issuer_guid': 'str',
        'org_id': 'str',
        'user_id': 'str',
        'user_object': 'UserSummary',
        'login_session': 'LoginSession',
        'upstream_idp': 'str',
        'ip_address': 'str',
        'amr_claim_present': 'bool',
        'last_mfa_login': 'datetime',
        'user_mfa_preferences': 'list[MFAChallengeMethod]'
    }

    attribute_map = {
        'user_preference': 'user_preference',
        'client_id': 'client_id',
        'client_guid': 'client_guid',
        'issuer_org_id': 'issuer_org_id',
        'issuer_guid': 'issuer_guid',
        'org_id': 'org_id',
        'user_id': 'user_id',
        'user_object': 'user_object',
        'login_session': 'login_session',
        'upstream_idp': 'upstream_idp',
        'ip_address': 'ip_address',
        'amr_claim_present': 'amr_claim_present',
        'last_mfa_login': 'last_mfa_login',
        'user_mfa_preferences': 'user_mfa_preferences'
    }

    def __init__(self, user_preference='organisation_policy', client_id=None, client_guid=None, issuer_org_id=None, issuer_guid=None, org_id=None, user_id=None, user_object=None, login_session=None, upstream_idp=None, ip_address=None, amr_claim_present=False, last_mfa_login=None, user_mfa_preferences=None, local_vars_configuration=None):  # noqa: E501
        """MFAChallengeQuestionLoginInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_preference = None
        self._client_id = None
        self._client_guid = None
        self._issuer_org_id = None
        self._issuer_guid = None
        self._org_id = None
        self._user_id = None
        self._user_object = None
        self._login_session = None
        self._upstream_idp = None
        self._ip_address = None
        self._amr_claim_present = None
        self._last_mfa_login = None
        self._user_mfa_preferences = None
        self.discriminator = None

        self.user_preference = user_preference
        self.client_id = client_id
        self.client_guid = client_guid
        self.issuer_org_id = issuer_org_id
        self.issuer_guid = issuer_guid
        self.org_id = org_id
        self.user_id = user_id
        if user_object is not None:
            self.user_object = user_object
        if login_session is not None:
            self.login_session = login_session
        self.upstream_idp = upstream_idp
        self.ip_address = ip_address
        self.amr_claim_present = amr_claim_present
        if last_mfa_login is not None:
            self.last_mfa_login = last_mfa_login
        if user_mfa_preferences is not None:
            self.user_mfa_preferences = user_mfa_preferences

    @property
    def user_preference(self):
        """Gets the user_preference of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The user's preference regarding multi-factor authentication  # noqa: E501

        :return: The user_preference of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_preference

    @user_preference.setter
    def user_preference(self, user_preference):
        """Sets the user_preference of this MFAChallengeQuestionLoginInfo.

        The user's preference regarding multi-factor authentication  # noqa: E501

        :param user_preference: The user_preference of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_preference is None:  # noqa: E501
            raise ValueError("Invalid value for `user_preference`, must not be `None`")  # noqa: E501
        allowed_values = ["always", "organisation_policy"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and user_preference not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `user_preference` ({0}), must be one of {1}"  # noqa: E501
                .format(user_preference, allowed_values)
            )

        self._user_preference = user_preference

    @property
    def client_id(self):
        """Gets the client_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The common name of the client initiating the request on behalf of the user  # noqa: E501

        :return: The client_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._client_id

    @client_id.setter
    def client_id(self, client_id):
        """Sets the client_id of this MFAChallengeQuestionLoginInfo.

        The common name of the client initiating the request on behalf of the user  # noqa: E501

        :param client_id: The client_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and client_id is None:  # noqa: E501
            raise ValueError("Invalid value for `client_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client_id is not None and len(client_id) > 100):
            raise ValueError("Invalid value for `client_id`, length must be less than or equal to `100`")  # noqa: E501

        self._client_id = client_id

    @property
    def client_guid(self):
        """Gets the client_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The guid of the client initiating the request on behalf of the user  # noqa: E501

        :return: The client_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._client_guid

    @client_guid.setter
    def client_guid(self, client_guid):
        """Sets the client_guid of this MFAChallengeQuestionLoginInfo.

        The guid of the client initiating the request on behalf of the user  # noqa: E501

        :param client_guid: The client_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and client_guid is None:  # noqa: E501
            raise ValueError("Invalid value for `client_guid`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                client_guid is not None and len(client_guid) > 40):
            raise ValueError("Invalid value for `client_guid`, length must be less than or equal to `40`")  # noqa: E501

        self._client_guid = client_guid

    @property
    def issuer_org_id(self):
        """Gets the issuer_org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The id of the organisation for the issuer the user is logging in through  # noqa: E501

        :return: The issuer_org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._issuer_org_id

    @issuer_org_id.setter
    def issuer_org_id(self, issuer_org_id):
        """Sets the issuer_org_id of this MFAChallengeQuestionLoginInfo.

        The id of the organisation for the issuer the user is logging in through  # noqa: E501

        :param issuer_org_id: The issuer_org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and issuer_org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `issuer_org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer_org_id is not None and len(issuer_org_id) > 40):
            raise ValueError("Invalid value for `issuer_org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._issuer_org_id = issuer_org_id

    @property
    def issuer_guid(self):
        """Gets the issuer_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The guid of the issuer the user is logging into.  # noqa: E501

        :return: The issuer_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._issuer_guid

    @issuer_guid.setter
    def issuer_guid(self, issuer_guid):
        """Sets the issuer_guid of this MFAChallengeQuestionLoginInfo.

        The guid of the issuer the user is logging into.  # noqa: E501

        :param issuer_guid: The issuer_guid of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and issuer_guid is None:  # noqa: E501
            raise ValueError("Invalid value for `issuer_guid`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer_guid is not None and len(issuer_guid) > 40):
            raise ValueError("Invalid value for `issuer_guid`, length must be less than or equal to `40`")  # noqa: E501

        self._issuer_guid = issuer_guid

    @property
    def org_id(self):
        """Gets the org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The id of the organisation the user is a member of  # noqa: E501

        :return: The org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this MFAChallengeQuestionLoginInfo.

        The id of the organisation the user is a member of  # noqa: E501

        :param org_id: The org_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._org_id = org_id

    @property
    def user_id(self):
        """Gets the user_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The id of the user requesting access  # noqa: E501

        :return: The user_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this MFAChallengeQuestionLoginInfo.

        The id of the user requesting access  # noqa: E501

        :param user_id: The user_id of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                user_id is not None and len(user_id) > 40):
            raise ValueError("Invalid value for `user_id`, length must be less than or equal to `40`")  # noqa: E501

        self._user_id = user_id

    @property
    def user_object(self):
        """Gets the user_object of this MFAChallengeQuestionLoginInfo.  # noqa: E501


        :return: The user_object of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: UserSummary
        """
        return self._user_object

    @user_object.setter
    def user_object(self, user_object):
        """Sets the user_object of this MFAChallengeQuestionLoginInfo.


        :param user_object: The user_object of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: UserSummary
        """

        self._user_object = user_object

    @property
    def login_session(self):
        """Gets the login_session of this MFAChallengeQuestionLoginInfo.  # noqa: E501


        :return: The login_session of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: LoginSession
        """
        return self._login_session

    @login_session.setter
    def login_session(self, login_session):
        """Sets the login_session of this MFAChallengeQuestionLoginInfo.


        :param login_session: The login_session of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: LoginSession
        """

        self._login_session = login_session

    @property
    def upstream_idp(self):
        """Gets the upstream_idp of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The upstream IDP that the user is authenticating against  # noqa: E501

        :return: The upstream_idp of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._upstream_idp

    @upstream_idp.setter
    def upstream_idp(self, upstream_idp):
        """Sets the upstream_idp of this MFAChallengeQuestionLoginInfo.

        The upstream IDP that the user is authenticating against  # noqa: E501

        :param upstream_idp: The upstream_idp of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and upstream_idp is None:  # noqa: E501
            raise ValueError("Invalid value for `upstream_idp`, must not be `None`")  # noqa: E501

        self._upstream_idp = upstream_idp

    @property
    def ip_address(self):
        """Gets the ip_address of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The source ip address of the user's request. Both IPv4 and IPv6 address are supported  # noqa: E501

        :return: The ip_address of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """Sets the ip_address of this MFAChallengeQuestionLoginInfo.

        The source ip address of the user's request. Both IPv4 and IPv6 address are supported  # noqa: E501

        :param ip_address: The ip_address of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ip_address is None:  # noqa: E501
            raise ValueError("Invalid value for `ip_address`, must not be `None`")  # noqa: E501

        self._ip_address = ip_address

    @property
    def amr_claim_present(self):
        """Gets the amr_claim_present of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        Whether the amr claim is present in the response from the upstream  # noqa: E501

        :return: The amr_claim_present of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: bool
        """
        return self._amr_claim_present

    @amr_claim_present.setter
    def amr_claim_present(self, amr_claim_present):
        """Sets the amr_claim_present of this MFAChallengeQuestionLoginInfo.

        Whether the amr claim is present in the response from the upstream  # noqa: E501

        :param amr_claim_present: The amr_claim_present of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and amr_claim_present is None:  # noqa: E501
            raise ValueError("Invalid value for `amr_claim_present`, must not be `None`")  # noqa: E501

        self._amr_claim_present = amr_claim_present

    @property
    def last_mfa_login(self):
        """Gets the last_mfa_login of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The time of the user's last successful multi-factor authenticated login  # noqa: E501

        :return: The last_mfa_login of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._last_mfa_login

    @last_mfa_login.setter
    def last_mfa_login(self, last_mfa_login):
        """Sets the last_mfa_login of this MFAChallengeQuestionLoginInfo.

        The time of the user's last successful multi-factor authenticated login  # noqa: E501

        :param last_mfa_login: The last_mfa_login of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: datetime
        """

        self._last_mfa_login = last_mfa_login

    @property
    def user_mfa_preferences(self):
        """Gets the user_mfa_preferences of this MFAChallengeQuestionLoginInfo.  # noqa: E501

        The list of a user's multi-factor challenge methods  # noqa: E501

        :return: The user_mfa_preferences of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :rtype: list[MFAChallengeMethod]
        """
        return self._user_mfa_preferences

    @user_mfa_preferences.setter
    def user_mfa_preferences(self, user_mfa_preferences):
        """Sets the user_mfa_preferences of this MFAChallengeQuestionLoginInfo.

        The list of a user's multi-factor challenge methods  # noqa: E501

        :param user_mfa_preferences: The user_mfa_preferences of this MFAChallengeQuestionLoginInfo.  # noqa: E501
        :type: list[MFAChallengeMethod]
        """

        self._user_mfa_preferences = user_mfa_preferences

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MFAChallengeQuestionLoginInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MFAChallengeQuestionLoginInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_share_stats import AgentConnectorShareStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorShareStats(unittest.TestCase):
    """AgentConnectorShareStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorShareStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_share_stats.AgentConnectorShareStats()  # noqa: E501
        if include_optional :
            return AgentConnectorShareStats(
                exposed_shares_count = 2, 
                server_running = True, 
                server_start_time = '2020-07-07T15:55:51.230Z', 
                server_stop_time = '2020-07-07T15:55:51.230Z', 
                server_start_count = 2, 
                server_stop_count = 1, 
                per_share_info = [
                    agilicus_api.models.agent_connector_per_share_stats.AgentConnectorPerShareStats(
                        share_prefix = '/public', 
                        share_id = '5s930sdfsdlA', 
                        local_path = '/home/user/shared', 
                        total_requests = 5132, 
                        successful_requests = 5102, 
                        failed_requests = 30, 
                        bytes_sent = 30458101, 
                        bytes_received = 9574339, 
                        share_start_time = '2020-07-07T15:55:52.230Z', )
                    ]
            )
        else :
            return AgentConnectorShareStats(
                exposed_shares_count = 2,
                server_running = True,
                server_start_count = 2,
                server_stop_count = 1,
                per_share_info = [
                    agilicus_api.models.agent_connector_per_share_stats.AgentConnectorPerShareStats(
                        share_prefix = '/public', 
                        share_id = '5s930sdfsdlA', 
                        local_path = '/home/user/shared', 
                        total_requests = 5132, 
                        successful_requests = 5102, 
                        failed_requests = 30, 
                        bytes_sent = 30458101, 
                        bytes_received = 9574339, 
                        share_start_time = '2020-07-07T15:55:52.230Z', )
                    ],
        )

    def testAgentConnectorShareStats(self):
        """Test AgentConnectorShareStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ServiceAccountSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'enabled': 'bool',
        'org_id': 'str',
        'allowed_sub_orgs': 'list[str]'
    }

    attribute_map = {
        'name': 'name',
        'enabled': 'enabled',
        'org_id': 'org_id',
        'allowed_sub_orgs': 'allowed_sub_orgs'
    }

    def __init__(self, name=None, enabled=None, org_id=None, allowed_sub_orgs=None, local_vars_configuration=None):  # noqa: E501
        """ServiceAccountSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._enabled = None
        self._org_id = None
        self._allowed_sub_orgs = None
        self.discriminator = None

        self.name = name
        if enabled is not None:
            self.enabled = enabled
        self.org_id = org_id
        if allowed_sub_orgs is not None:
            self.allowed_sub_orgs = allowed_sub_orgs

    @property
    def name(self):
        """Gets the name of this ServiceAccountSpec.  # noqa: E501

        The name of the service account. This will be used as part of the generated email for the service account. Note the service account's email will not be updated after it has been created.   # noqa: E501

        :return: The name of this ServiceAccountSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ServiceAccountSpec.

        The name of the service account. This will be used as part of the generated email for the service account. Note the service account's email will not be updated after it has been created.   # noqa: E501

        :param name: The name of this ServiceAccountSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def enabled(self):
        """Gets the enabled of this ServiceAccountSpec.  # noqa: E501

        Enable/Disable a service account. This will enable/disable the service account user associated with this account.  # noqa: E501

        :return: The enabled of this ServiceAccountSpec.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ServiceAccountSpec.

        Enable/Disable a service account. This will enable/disable the service account user associated with this account.  # noqa: E501

        :param enabled: The enabled of this ServiceAccountSpec.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def org_id(self):
        """Gets the org_id of this ServiceAccountSpec.  # noqa: E501

        The unique id of the Organisation to which this service account belongs to. This restricts the possible values for allowed_sub_orgs   # noqa: E501

        :return: The org_id of this ServiceAccountSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this ServiceAccountSpec.

        The unique id of the Organisation to which this service account belongs to. This restricts the possible values for allowed_sub_orgs   # noqa: E501

        :param org_id: The org_id of this ServiceAccountSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) < 1):
            raise ValueError("Invalid value for `org_id`, length must be greater than or equal to `1`")  # noqa: E501

        self._org_id = org_id

    @property
    def allowed_sub_orgs(self):
        """Gets the allowed_sub_orgs of this ServiceAccountSpec.  # noqa: E501

        The list of suborgs that this service account can be used in. To enable this service account in a sub organisation, activate this service account's user in the organisation.  # noqa: E501

        :return: The allowed_sub_orgs of this ServiceAccountSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._allowed_sub_orgs

    @allowed_sub_orgs.setter
    def allowed_sub_orgs(self, allowed_sub_orgs):
        """Sets the allowed_sub_orgs of this ServiceAccountSpec.

        The list of suborgs that this service account can be used in. To enable this service account in a sub organisation, activate this service account's user in the organisation.  # noqa: E501

        :param allowed_sub_orgs: The allowed_sub_orgs of this ServiceAccountSpec.  # noqa: E501
        :type: list[str]
        """

        self._allowed_sub_orgs = allowed_sub_orgs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServiceAccountSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ServiceAccountSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class IpsecConnectionSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ike_version': 'str',
        'remote_ipv4_address': 'str',
        'remote_dns_ipv4_address': 'str',
        'remote_healthcheck_ipv4_address': 'str',
        'ike_cipher_encryption_algorithm': 'CipherEncryptionAlgorithm',
        'ike_cipher_integrity_algorithm': 'CipherIntegrityAlgorithm',
        'ike_cipher_diffie_hellman_group': 'CipherDiffieHellmanGroup',
        'esp_cipher_encryption_algorithm': 'CipherEncryptionAlgorithm',
        'esp_cipher_integrity_algorithm': 'CipherIntegrityAlgorithm',
        'esp_cipher_diffie_hellman_group': 'CipherDiffieHellmanGroup',
        'esp_lifetime': 'int',
        'ike_lifetime': 'int',
        'ike_rekey': 'bool',
        'ike_reauth': 'bool',
        'ike_authentication_type': 'str',
        'ike_preshared_key': 'str',
        'ike_chain_of_trust_certificates': 'str',
        'ike_certificate_dn': 'str',
        'local_ipv4_block': 'str',
        'remote_ipv4_ranges': 'list[IpsecConnectionIpv4Block]'
    }

    attribute_map = {
        'ike_version': 'ike_version',
        'remote_ipv4_address': 'remote_ipv4_address',
        'remote_dns_ipv4_address': 'remote_dns_ipv4_address',
        'remote_healthcheck_ipv4_address': 'remote_healthcheck_ipv4_address',
        'ike_cipher_encryption_algorithm': 'ike_cipher_encryption_algorithm',
        'ike_cipher_integrity_algorithm': 'ike_cipher_integrity_algorithm',
        'ike_cipher_diffie_hellman_group': 'ike_cipher_diffie_hellman_group',
        'esp_cipher_encryption_algorithm': 'esp_cipher_encryption_algorithm',
        'esp_cipher_integrity_algorithm': 'esp_cipher_integrity_algorithm',
        'esp_cipher_diffie_hellman_group': 'esp_cipher_diffie_hellman_group',
        'esp_lifetime': 'esp_lifetime',
        'ike_lifetime': 'ike_lifetime',
        'ike_rekey': 'ike_rekey',
        'ike_reauth': 'ike_reauth',
        'ike_authentication_type': 'ike_authentication_type',
        'ike_preshared_key': 'ike_preshared_key',
        'ike_chain_of_trust_certificates': 'ike_chain_of_trust_certificates',
        'ike_certificate_dn': 'ike_certificate_dn',
        'local_ipv4_block': 'local_ipv4_block',
        'remote_ipv4_ranges': 'remote_ipv4_ranges'
    }

    def __init__(self, ike_version=None, remote_ipv4_address=None, remote_dns_ipv4_address=None, remote_healthcheck_ipv4_address=None, ike_cipher_encryption_algorithm=None, ike_cipher_integrity_algorithm=None, ike_cipher_diffie_hellman_group=None, esp_cipher_encryption_algorithm=None, esp_cipher_integrity_algorithm=None, esp_cipher_diffie_hellman_group=None, esp_lifetime=None, ike_lifetime=None, ike_rekey=None, ike_reauth=None, ike_authentication_type=None, ike_preshared_key=None, ike_chain_of_trust_certificates=None, ike_certificate_dn=None, local_ipv4_block=None, remote_ipv4_ranges=None, local_vars_configuration=None):  # noqa: E501
        """IpsecConnectionSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ike_version = None
        self._remote_ipv4_address = None
        self._remote_dns_ipv4_address = None
        self._remote_healthcheck_ipv4_address = None
        self._ike_cipher_encryption_algorithm = None
        self._ike_cipher_integrity_algorithm = None
        self._ike_cipher_diffie_hellman_group = None
        self._esp_cipher_encryption_algorithm = None
        self._esp_cipher_integrity_algorithm = None
        self._esp_cipher_diffie_hellman_group = None
        self._esp_lifetime = None
        self._ike_lifetime = None
        self._ike_rekey = None
        self._ike_reauth = None
        self._ike_authentication_type = None
        self._ike_preshared_key = None
        self._ike_chain_of_trust_certificates = None
        self._ike_certificate_dn = None
        self._local_ipv4_block = None
        self._remote_ipv4_ranges = None
        self.discriminator = None

        if ike_version is not None:
            self.ike_version = ike_version
        if remote_ipv4_address is not None:
            self.remote_ipv4_address = remote_ipv4_address
        if remote_dns_ipv4_address is not None:
            self.remote_dns_ipv4_address = remote_dns_ipv4_address
        if remote_healthcheck_ipv4_address is not None:
            self.remote_healthcheck_ipv4_address = remote_healthcheck_ipv4_address
        if ike_cipher_encryption_algorithm is not None:
            self.ike_cipher_encryption_algorithm = ike_cipher_encryption_algorithm
        if ike_cipher_integrity_algorithm is not None:
            self.ike_cipher_integrity_algorithm = ike_cipher_integrity_algorithm
        if ike_cipher_diffie_hellman_group is not None:
            self.ike_cipher_diffie_hellman_group = ike_cipher_diffie_hellman_group
        if esp_cipher_encryption_algorithm is not None:
            self.esp_cipher_encryption_algorithm = esp_cipher_encryption_algorithm
        if esp_cipher_integrity_algorithm is not None:
            self.esp_cipher_integrity_algorithm = esp_cipher_integrity_algorithm
        if esp_cipher_diffie_hellman_group is not None:
            self.esp_cipher_diffie_hellman_group = esp_cipher_diffie_hellman_group
        if esp_lifetime is not None:
            self.esp_lifetime = esp_lifetime
        if ike_lifetime is not None:
            self.ike_lifetime = ike_lifetime
        if ike_rekey is not None:
            self.ike_rekey = ike_rekey
        if ike_reauth is not None:
            self.ike_reauth = ike_reauth
        if ike_authentication_type is not None:
            self.ike_authentication_type = ike_authentication_type
        if ike_preshared_key is not None:
            self.ike_preshared_key = ike_preshared_key
        if ike_chain_of_trust_certificates is not None:
            self.ike_chain_of_trust_certificates = ike_chain_of_trust_certificates
        if ike_certificate_dn is not None:
            self.ike_certificate_dn = ike_certificate_dn
        if local_ipv4_block is not None:
            self.local_ipv4_block = local_ipv4_block
        if remote_ipv4_ranges is not None:
            self.remote_ipv4_ranges = remote_ipv4_ranges

    @property
    def ike_version(self):
        """Gets the ike_version of this IpsecConnectionSpec.  # noqa: E501

        The IKE version  # noqa: E501

        :return: The ike_version of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ike_version

    @ike_version.setter
    def ike_version(self, ike_version):
        """Sets the ike_version of this IpsecConnectionSpec.

        The IKE version  # noqa: E501

        :param ike_version: The ike_version of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """
        allowed_values = ["ikev1", "ikev2"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ike_version not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `ike_version` ({0}), must be one of {1}"  # noqa: E501
                .format(ike_version, allowed_values)
            )

        self._ike_version = ike_version

    @property
    def remote_ipv4_address(self):
        """Gets the remote_ipv4_address of this IpsecConnectionSpec.  # noqa: E501

        remote peer IPv4 address  # noqa: E501

        :return: The remote_ipv4_address of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._remote_ipv4_address

    @remote_ipv4_address.setter
    def remote_ipv4_address(self, remote_ipv4_address):
        """Sets the remote_ipv4_address of this IpsecConnectionSpec.

        remote peer IPv4 address  # noqa: E501

        :param remote_ipv4_address: The remote_ipv4_address of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """

        self._remote_ipv4_address = remote_ipv4_address

    @property
    def remote_dns_ipv4_address(self):
        """Gets the remote_dns_ipv4_address of this IpsecConnectionSpec.  # noqa: E501

        remote peer DNS IPv4 address  # noqa: E501

        :return: The remote_dns_ipv4_address of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._remote_dns_ipv4_address

    @remote_dns_ipv4_address.setter
    def remote_dns_ipv4_address(self, remote_dns_ipv4_address):
        """Sets the remote_dns_ipv4_address of this IpsecConnectionSpec.

        remote peer DNS IPv4 address  # noqa: E501

        :param remote_dns_ipv4_address: The remote_dns_ipv4_address of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """

        self._remote_dns_ipv4_address = remote_dns_ipv4_address

    @property
    def remote_healthcheck_ipv4_address(self):
        """Gets the remote_healthcheck_ipv4_address of this IpsecConnectionSpec.  # noqa: E501

        Remote peer healthcheck IPv4 address. The remote peer address must respond to ping (ICMP). This is used to validate the health of the connection.   # noqa: E501

        :return: The remote_healthcheck_ipv4_address of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._remote_healthcheck_ipv4_address

    @remote_healthcheck_ipv4_address.setter
    def remote_healthcheck_ipv4_address(self, remote_healthcheck_ipv4_address):
        """Sets the remote_healthcheck_ipv4_address of this IpsecConnectionSpec.

        Remote peer healthcheck IPv4 address. The remote peer address must respond to ping (ICMP). This is used to validate the health of the connection.   # noqa: E501

        :param remote_healthcheck_ipv4_address: The remote_healthcheck_ipv4_address of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """

        self._remote_healthcheck_ipv4_address = remote_healthcheck_ipv4_address

    @property
    def ike_cipher_encryption_algorithm(self):
        """Gets the ike_cipher_encryption_algorithm of this IpsecConnectionSpec.  # noqa: E501


        :return: The ike_cipher_encryption_algorithm of this IpsecConnectionSpec.  # noqa: E501
        :rtype: CipherEncryptionAlgorithm
        """
        return self._ike_cipher_encryption_algorithm

    @ike_cipher_encryption_algorithm.setter
    def ike_cipher_encryption_algorithm(self, ike_cipher_encryption_algorithm):
        """Sets the ike_cipher_encryption_algorithm of this IpsecConnectionSpec.


        :param ike_cipher_encryption_algorithm: The ike_cipher_encryption_algorithm of this IpsecConnectionSpec.  # noqa: E501
        :type: CipherEncryptionAlgorithm
        """

        self._ike_cipher_encryption_algorithm = ike_cipher_encryption_algorithm

    @property
    def ike_cipher_integrity_algorithm(self):
        """Gets the ike_cipher_integrity_algorithm of this IpsecConnectionSpec.  # noqa: E501


        :return: The ike_cipher_integrity_algorithm of this IpsecConnectionSpec.  # noqa: E501
        :rtype: CipherIntegrityAlgorithm
        """
        return self._ike_cipher_integrity_algorithm

    @ike_cipher_integrity_algorithm.setter
    def ike_cipher_integrity_algorithm(self, ike_cipher_integrity_algorithm):
        """Sets the ike_cipher_integrity_algorithm of this IpsecConnectionSpec.


        :param ike_cipher_integrity_algorithm: The ike_cipher_integrity_algorithm of this IpsecConnectionSpec.  # noqa: E501
        :type: CipherIntegrityAlgorithm
        """

        self._ike_cipher_integrity_algorithm = ike_cipher_integrity_algorithm

    @property
    def ike_cipher_diffie_hellman_group(self):
        """Gets the ike_cipher_diffie_hellman_group of this IpsecConnectionSpec.  # noqa: E501


        :return: The ike_cipher_diffie_hellman_group of this IpsecConnectionSpec.  # noqa: E501
        :rtype: CipherDiffieHellmanGroup
        """
        return self._ike_cipher_diffie_hellman_group

    @ike_cipher_diffie_hellman_group.setter
    def ike_cipher_diffie_hellman_group(self, ike_cipher_diffie_hellman_group):
        """Sets the ike_cipher_diffie_hellman_group of this IpsecConnectionSpec.


        :param ike_cipher_diffie_hellman_group: The ike_cipher_diffie_hellman_group of this IpsecConnectionSpec.  # noqa: E501
        :type: CipherDiffieHellmanGroup
        """

        self._ike_cipher_diffie_hellman_group = ike_cipher_diffie_hellman_group

    @property
    def esp_cipher_encryption_algorithm(self):
        """Gets the esp_cipher_encryption_algorithm of this IpsecConnectionSpec.  # noqa: E501


        :return: The esp_cipher_encryption_algorithm of this IpsecConnectionSpec.  # noqa: E501
        :rtype: CipherEncryptionAlgorithm
        """
        return self._esp_cipher_encryption_algorithm

    @esp_cipher_encryption_algorithm.setter
    def esp_cipher_encryption_algorithm(self, esp_cipher_encryption_algorithm):
        """Sets the esp_cipher_encryption_algorithm of this IpsecConnectionSpec.


        :param esp_cipher_encryption_algorithm: The esp_cipher_encryption_algorithm of this IpsecConnectionSpec.  # noqa: E501
        :type: CipherEncryptionAlgorithm
        """

        self._esp_cipher_encryption_algorithm = esp_cipher_encryption_algorithm

    @property
    def esp_cipher_integrity_algorithm(self):
        """Gets the esp_cipher_integrity_algorithm of this IpsecConnectionSpec.  # noqa: E501


        :return: The esp_cipher_integrity_algorithm of this IpsecConnectionSpec.  # noqa: E501
        :rtype: CipherIntegrityAlgorithm
        """
        return self._esp_cipher_integrity_algorithm

    @esp_cipher_integrity_algorithm.setter
    def esp_cipher_integrity_algorithm(self, esp_cipher_integrity_algorithm):
        """Sets the esp_cipher_integrity_algorithm of this IpsecConnectionSpec.


        :param esp_cipher_integrity_algorithm: The esp_cipher_integrity_algorithm of this IpsecConnectionSpec.  # noqa: E501
        :type: CipherIntegrityAlgorithm
        """

        self._esp_cipher_integrity_algorithm = esp_cipher_integrity_algorithm

    @property
    def esp_cipher_diffie_hellman_group(self):
        """Gets the esp_cipher_diffie_hellman_group of this IpsecConnectionSpec.  # noqa: E501


        :return: The esp_cipher_diffie_hellman_group of this IpsecConnectionSpec.  # noqa: E501
        :rtype: CipherDiffieHellmanGroup
        """
        return self._esp_cipher_diffie_hellman_group

    @esp_cipher_diffie_hellman_group.setter
    def esp_cipher_diffie_hellman_group(self, esp_cipher_diffie_hellman_group):
        """Sets the esp_cipher_diffie_hellman_group of this IpsecConnectionSpec.


        :param esp_cipher_diffie_hellman_group: The esp_cipher_diffie_hellman_group of this IpsecConnectionSpec.  # noqa: E501
        :type: CipherDiffieHellmanGroup
        """

        self._esp_cipher_diffie_hellman_group = esp_cipher_diffie_hellman_group

    @property
    def esp_lifetime(self):
        """Gets the esp_lifetime of this IpsecConnectionSpec.  # noqa: E501

        Absolute time after which an IPsec security association expires, in minutes.   # noqa: E501

        :return: The esp_lifetime of this IpsecConnectionSpec.  # noqa: E501
        :rtype: int
        """
        return self._esp_lifetime

    @esp_lifetime.setter
    def esp_lifetime(self, esp_lifetime):
        """Sets the esp_lifetime of this IpsecConnectionSpec.

        Absolute time after which an IPsec security association expires, in minutes.   # noqa: E501

        :param esp_lifetime: The esp_lifetime of this IpsecConnectionSpec.  # noqa: E501
        :type: int
        """

        self._esp_lifetime = esp_lifetime

    @property
    def ike_lifetime(self):
        """Gets the ike_lifetime of this IpsecConnectionSpec.  # noqa: E501

        Absolute time after which an IKE security association expires, in minutes.   # noqa: E501

        :return: The ike_lifetime of this IpsecConnectionSpec.  # noqa: E501
        :rtype: int
        """
        return self._ike_lifetime

    @ike_lifetime.setter
    def ike_lifetime(self, ike_lifetime):
        """Sets the ike_lifetime of this IpsecConnectionSpec.

        Absolute time after which an IKE security association expires, in minutes.   # noqa: E501

        :param ike_lifetime: The ike_lifetime of this IpsecConnectionSpec.  # noqa: E501
        :type: int
        """

        self._ike_lifetime = ike_lifetime

    @property
    def ike_rekey(self):
        """Gets the ike_rekey of this IpsecConnectionSpec.  # noqa: E501

        Allows control of IKE rekey.  true is enabled, false is disabled.   # noqa: E501

        :return: The ike_rekey of this IpsecConnectionSpec.  # noqa: E501
        :rtype: bool
        """
        return self._ike_rekey

    @ike_rekey.setter
    def ike_rekey(self, ike_rekey):
        """Sets the ike_rekey of this IpsecConnectionSpec.

        Allows control of IKE rekey.  true is enabled, false is disabled.   # noqa: E501

        :param ike_rekey: The ike_rekey of this IpsecConnectionSpec.  # noqa: E501
        :type: bool
        """

        self._ike_rekey = ike_rekey

    @property
    def ike_reauth(self):
        """Gets the ike_reauth of this IpsecConnectionSpec.  # noqa: E501

        Allows control of IKE re-authentication.  true is enabled, false is disabled.   # noqa: E501

        :return: The ike_reauth of this IpsecConnectionSpec.  # noqa: E501
        :rtype: bool
        """
        return self._ike_reauth

    @ike_reauth.setter
    def ike_reauth(self, ike_reauth):
        """Sets the ike_reauth of this IpsecConnectionSpec.

        Allows control of IKE re-authentication.  true is enabled, false is disabled.   # noqa: E501

        :param ike_reauth: The ike_reauth of this IpsecConnectionSpec.  # noqa: E501
        :type: bool
        """

        self._ike_reauth = ike_reauth

    @property
    def ike_authentication_type(self):
        """Gets the ike_authentication_type of this IpsecConnectionSpec.  # noqa: E501

        The IKE authentication type.  # noqa: E501

        :return: The ike_authentication_type of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ike_authentication_type

    @ike_authentication_type.setter
    def ike_authentication_type(self, ike_authentication_type):
        """Sets the ike_authentication_type of this IpsecConnectionSpec.

        The IKE authentication type.  # noqa: E501

        :param ike_authentication_type: The ike_authentication_type of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """
        allowed_values = ["ike_preshared_key", "certificate"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ike_authentication_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `ike_authentication_type` ({0}), must be one of {1}"  # noqa: E501
                .format(ike_authentication_type, allowed_values)
            )

        self._ike_authentication_type = ike_authentication_type

    @property
    def ike_preshared_key(self):
        """Gets the ike_preshared_key of this IpsecConnectionSpec.  # noqa: E501

        ike preshared key  # noqa: E501

        :return: The ike_preshared_key of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ike_preshared_key

    @ike_preshared_key.setter
    def ike_preshared_key(self, ike_preshared_key):
        """Sets the ike_preshared_key of this IpsecConnectionSpec.

        ike preshared key  # noqa: E501

        :param ike_preshared_key: The ike_preshared_key of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """

        self._ike_preshared_key = ike_preshared_key

    @property
    def ike_chain_of_trust_certificates(self):
        """Gets the ike_chain_of_trust_certificates of this IpsecConnectionSpec.  # noqa: E501

        Chain of trust certficates. Certificates are PEM encoded and are separated by a newline.  ie. A signed by B would be a string where A is first, newline, followed by B.   # noqa: E501

        :return: The ike_chain_of_trust_certificates of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ike_chain_of_trust_certificates

    @ike_chain_of_trust_certificates.setter
    def ike_chain_of_trust_certificates(self, ike_chain_of_trust_certificates):
        """Sets the ike_chain_of_trust_certificates of this IpsecConnectionSpec.

        Chain of trust certficates. Certificates are PEM encoded and are separated by a newline.  ie. A signed by B would be a string where A is first, newline, followed by B.   # noqa: E501

        :param ike_chain_of_trust_certificates: The ike_chain_of_trust_certificates of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """

        self._ike_chain_of_trust_certificates = ike_chain_of_trust_certificates

    @property
    def ike_certificate_dn(self):
        """Gets the ike_certificate_dn of this IpsecConnectionSpec.  # noqa: E501

        certificate distinguished name (DN)  # noqa: E501

        :return: The ike_certificate_dn of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._ike_certificate_dn

    @ike_certificate_dn.setter
    def ike_certificate_dn(self, ike_certificate_dn):
        """Sets the ike_certificate_dn of this IpsecConnectionSpec.

        certificate distinguished name (DN)  # noqa: E501

        :param ike_certificate_dn: The ike_certificate_dn of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """

        self._ike_certificate_dn = ike_certificate_dn

    @property
    def local_ipv4_block(self):
        """Gets the local_ipv4_block of this IpsecConnectionSpec.  # noqa: E501

        The local IP block that used by the tunnel. A tunnel requires a /30 subnet, within the following IP address ranges    192.168.0.0 -> 192.168.255.252   172.16.0.0 -> 172.31.255.255   # noqa: E501

        :return: The local_ipv4_block of this IpsecConnectionSpec.  # noqa: E501
        :rtype: str
        """
        return self._local_ipv4_block

    @local_ipv4_block.setter
    def local_ipv4_block(self, local_ipv4_block):
        """Sets the local_ipv4_block of this IpsecConnectionSpec.

        The local IP block that used by the tunnel. A tunnel requires a /30 subnet, within the following IP address ranges    192.168.0.0 -> 192.168.255.252   172.16.0.0 -> 172.31.255.255   # noqa: E501

        :param local_ipv4_block: The local_ipv4_block of this IpsecConnectionSpec.  # noqa: E501
        :type: str
        """

        self._local_ipv4_block = local_ipv4_block

    @property
    def remote_ipv4_ranges(self):
        """Gets the remote_ipv4_ranges of this IpsecConnectionSpec.  # noqa: E501

        One or more IP address ranges that define the peer network range.   # noqa: E501

        :return: The remote_ipv4_ranges of this IpsecConnectionSpec.  # noqa: E501
        :rtype: list[IpsecConnectionIpv4Block]
        """
        return self._remote_ipv4_ranges

    @remote_ipv4_ranges.setter
    def remote_ipv4_ranges(self, remote_ipv4_ranges):
        """Sets the remote_ipv4_ranges of this IpsecConnectionSpec.

        One or more IP address ranges that define the peer network range.   # noqa: E501

        :param remote_ipv4_ranges: The remote_ipv4_ranges of this IpsecConnectionSpec.  # noqa: E501
        :type: list[IpsecConnectionIpv4Block]
        """

        self._remote_ipv4_ranges = remote_ipv4_ranges

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IpsecConnectionSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IpsecConnectionSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class FileShareServiceSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'share_name': 'str',
        'org_id': 'str',
        'local_path': 'str',
        'connector_id': 'str',
        'share_index': 'int',
        'transport_end_to_end_tls': 'bool',
        'transport_base_domain': 'str'
    }

    attribute_map = {
        'name': 'name',
        'share_name': 'share_name',
        'org_id': 'org_id',
        'local_path': 'local_path',
        'connector_id': 'connector_id',
        'share_index': 'share_index',
        'transport_end_to_end_tls': 'transport_end_to_end_tls',
        'transport_base_domain': 'transport_base_domain'
    }

    def __init__(self, name=None, share_name=None, org_id=None, local_path=None, connector_id=None, share_index=None, transport_end_to_end_tls=None, transport_base_domain=None, local_vars_configuration=None):  # noqa: E501
        """FileShareServiceSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._share_name = None
        self._org_id = None
        self._local_path = None
        self._connector_id = None
        self._share_index = None
        self._transport_end_to_end_tls = None
        self._transport_base_domain = None
        self.discriminator = None

        self.name = name
        self.share_name = share_name
        self.org_id = org_id
        self.local_path = local_path
        self.connector_id = connector_id
        if share_index is not None:
            self.share_index = share_index
        if transport_end_to_end_tls is not None:
            self.transport_end_to_end_tls = transport_end_to_end_tls
        if transport_base_domain is not None:
            self.transport_base_domain = transport_base_domain

    @property
    def name(self):
        """Gets the name of this FileShareServiceSpec.  # noqa: E501

        The name of the service. This uniquely identifies the service within the organisation.   # noqa: E501

        :return: The name of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileShareServiceSpec.

        The name of the service. This uniquely identifies the service within the organisation.   # noqa: E501

        :param name: The name of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def share_name(self):
        """Gets the share_name of this FileShareServiceSpec.  # noqa: E501

        The name of the share as exposed to the Internet. This will be used to build the URI used to mount the share. The share_name is unique among the file shares of the organisation.   # noqa: E501

        :return: The share_name of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._share_name

    @share_name.setter
    def share_name(self, share_name):
        """Sets the share_name of this FileShareServiceSpec.

        The name of the share as exposed to the Internet. This will be used to build the URI used to mount the share. The share_name is unique among the file shares of the organisation.   # noqa: E501

        :param share_name: The share_name of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and share_name is None:  # noqa: E501
            raise ValueError("Invalid value for `share_name`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                share_name is not None and len(share_name) > 1024):
            raise ValueError("Invalid value for `share_name`, length must be less than or equal to `1024`")  # noqa: E501

        self._share_name = share_name

    @property
    def org_id(self):
        """Gets the org_id of this FileShareServiceSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this FileShareServiceSpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def local_path(self):
        """Gets the local_path of this FileShareServiceSpec.  # noqa: E501

        The path to the directory to share on the local file system. This should point to a directory, not a file. Use a slash ('/', U+002F) to separate directories within the path.   # noqa: E501

        :return: The local_path of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._local_path

    @local_path.setter
    def local_path(self, local_path):
        """Sets the local_path of this FileShareServiceSpec.

        The path to the directory to share on the local file system. This should point to a directory, not a file. Use a slash ('/', U+002F) to separate directories within the path.   # noqa: E501

        :param local_path: The local_path of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and local_path is None:  # noqa: E501
            raise ValueError("Invalid value for `local_path`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                local_path is not None and len(local_path) > 4096):
            raise ValueError("Invalid value for `local_path`, length must be less than or equal to `4096`")  # noqa: E501

        self._local_path = local_path

    @property
    def connector_id(self):
        """Gets the connector_id of this FileShareServiceSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The connector_id of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._connector_id

    @connector_id.setter
    def connector_id(self, connector_id):
        """Sets the connector_id of this FileShareServiceSpec.

        Unique identifier  # noqa: E501

        :param connector_id: The connector_id of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and connector_id is None:  # noqa: E501
            raise ValueError("Invalid value for `connector_id`, must not be `None`")  # noqa: E501

        self._connector_id = connector_id

    @property
    def share_index(self):
        """Gets the share_index of this FileShareServiceSpec.  # noqa: E501

        The index of the FileShareService. This is used to construct a unique URI at which to access this FileShareService.   # noqa: E501

        :return: The share_index of this FileShareServiceSpec.  # noqa: E501
        :rtype: int
        """
        return self._share_index

    @share_index.setter
    def share_index(self, share_index):
        """Sets the share_index of this FileShareServiceSpec.

        The index of the FileShareService. This is used to construct a unique URI at which to access this FileShareService.   # noqa: E501

        :param share_index: The share_index of this FileShareServiceSpec.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                share_index is not None and share_index > 4294967295):  # noqa: E501
            raise ValueError("Invalid value for `share_index`, must be a value less than or equal to `4294967295`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                share_index is not None and share_index < 1):  # noqa: E501
            raise ValueError("Invalid value for `share_index`, must be a value greater than or equal to `1`")  # noqa: E501

        self._share_index = share_index

    @property
    def transport_end_to_end_tls(self):
        """Gets the transport_end_to_end_tls of this FileShareServiceSpec.  # noqa: E501

        Whether or not the FileShareService encrypts data using the same Transport Layer Security (TLS) session as seen by the client. Setting this to true will cause the FileShareService to provision a Certificate signed by a private key only known to it. All traffic to and from the FileShareService will be encrypted using a TLS session derived from that Certificate. Setting this to false will cause the FileShareService to use a TLS session derived from a Certificate provisioned by the Agilicus Cloud.   # noqa: E501

        :return: The transport_end_to_end_tls of this FileShareServiceSpec.  # noqa: E501
        :rtype: bool
        """
        return self._transport_end_to_end_tls

    @transport_end_to_end_tls.setter
    def transport_end_to_end_tls(self, transport_end_to_end_tls):
        """Sets the transport_end_to_end_tls of this FileShareServiceSpec.

        Whether or not the FileShareService encrypts data using the same Transport Layer Security (TLS) session as seen by the client. Setting this to true will cause the FileShareService to provision a Certificate signed by a private key only known to it. All traffic to and from the FileShareService will be encrypted using a TLS session derived from that Certificate. Setting this to false will cause the FileShareService to use a TLS session derived from a Certificate provisioned by the Agilicus Cloud.   # noqa: E501

        :param transport_end_to_end_tls: The transport_end_to_end_tls of this FileShareServiceSpec.  # noqa: E501
        :type: bool
        """

        self._transport_end_to_end_tls = transport_end_to_end_tls

    @property
    def transport_base_domain(self):
        """Gets the transport_base_domain of this FileShareServiceSpec.  # noqa: E501

        The base domain from which to access this share. The file share endpoint will be \"https://share-$(share_index).$(base_domain)\"   # noqa: E501

        :return: The transport_base_domain of this FileShareServiceSpec.  # noqa: E501
        :rtype: str
        """
        return self._transport_base_domain

    @transport_base_domain.setter
    def transport_base_domain(self, transport_base_domain):
        """Sets the transport_base_domain of this FileShareServiceSpec.

        The base domain from which to access this share. The file share endpoint will be \"https://share-$(share_index).$(base_domain)\"   # noqa: E501

        :param transport_base_domain: The transport_base_domain of this FileShareServiceSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                transport_base_domain is not None and len(transport_base_domain) > 240):
            raise ValueError("Invalid value for `transport_base_domain`, length must be less than or equal to `240`")  # noqa: E501

        self._transport_base_domain = transport_base_domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileShareServiceSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileShareServiceSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.create_session_and_token_response import CreateSessionAndTokenResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestCreateSessionAndTokenResponse(unittest.TestCase):
    """CreateSessionAndTokenResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateSessionAndTokenResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.create_session_and_token_response.CreateSessionAndTokenResponse()  # noqa: E501
        if include_optional :
            return CreateSessionAndTokenResponse(
                token = agilicus_api.models.raw_token.RawToken(
                    token = '0', 
                    session = '123', 
                    time_validity = agilicus_api.models.time_validity.TimeValidity(
                        duration = 56, ), ), 
                session = agilicus_api.models.session.Session(
                    metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                    spec = agilicus_api.models.sessions_spec.SessionsSpec(
                        user_id = 'asdfghjklmn123', 
                        org_id = 'asdfghjklmn123', 
                        revoked = False, 
                        number_of_logins = 3, 
                        number_of_failed_multi_factor_challenges = 3, ), )
            )
        else :
            return CreateSessionAndTokenResponse(
        )

    def testCreateSessionAndTokenResponse(self):
        """Test CreateSessionAndTokenResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class BaseUpstream(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'issuer': 'str',
        'upstream_type': 'str',
        'icon': 'str',
        'auto_create_status': 'AutoCreateStatus'
    }

    attribute_map = {
        'name': 'name',
        'issuer': 'issuer',
        'upstream_type': 'upstream_type',
        'icon': 'icon',
        'auto_create_status': 'auto_create_status'
    }

    def __init__(self, name=None, issuer=None, upstream_type=None, icon=None, auto_create_status=None, local_vars_configuration=None):  # noqa: E501
        """BaseUpstream - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._issuer = None
        self._upstream_type = None
        self._icon = None
        self._auto_create_status = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if issuer is not None:
            self.issuer = issuer
        if upstream_type is not None:
            self.upstream_type = upstream_type
        if icon is not None:
            self.icon = icon
        if auto_create_status is not None:
            self.auto_create_status = auto_create_status

    @property
    def name(self):
        """Gets the name of this BaseUpstream.  # noqa: E501

        A name used to uniquely refer to the upstream identity provider configuration. This is the text that will be displayed when presenting the upstream identity for login.  # noqa: E501

        :return: The name of this BaseUpstream.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this BaseUpstream.

        A name used to uniquely refer to the upstream identity provider configuration. This is the text that will be displayed when presenting the upstream identity for login.  # noqa: E501

        :param name: The name of this BaseUpstream.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def issuer(self):
        """Gets the issuer of this BaseUpstream.  # noqa: E501

        The upstream issuer uri. This is the URI which identifies the issuer against which users selecting this upstream will authenticate.  # noqa: E501

        :return: The issuer of this BaseUpstream.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this BaseUpstream.

        The upstream issuer uri. This is the URI which identifies the issuer against which users selecting this upstream will authenticate.  # noqa: E501

        :param issuer: The issuer of this BaseUpstream.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                issuer is not None and len(issuer) > 511):
            raise ValueError("Invalid value for `issuer`, length must be less than or equal to `511`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer is not None and len(issuer) < 1):
            raise ValueError("Invalid value for `issuer`, length must be greater than or equal to `1`")  # noqa: E501

        self._issuer = issuer

    @property
    def upstream_type(self):
        """Gets the upstream_type of this BaseUpstream.  # noqa: E501

        The type of upstream. For instance an OpenID Connector Upstream.  # noqa: E501

        :return: The upstream_type of this BaseUpstream.  # noqa: E501
        :rtype: str
        """
        return self._upstream_type

    @upstream_type.setter
    def upstream_type(self, upstream_type):
        """Sets the upstream_type of this BaseUpstream.

        The type of upstream. For instance an OpenID Connector Upstream.  # noqa: E501

        :param upstream_type: The upstream_type of this BaseUpstream.  # noqa: E501
        :type: str
        """
        allowed_values = ["oidc", "local_auth"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and upstream_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `upstream_type` ({0}), must be one of {1}"  # noqa: E501
                .format(upstream_type, allowed_values)
            )

        self._upstream_type = upstream_type

    @property
    def icon(self):
        """Gets the icon of this BaseUpstream.  # noqa: E501

        The icon file to be used, limited to: numbers, letters, underscores, hyphens and periods. It is part of a css class (with the periods replaced by underscores).  To use a custom icon than the provided default you will need to add the icon the static/img folder and update the static css file to add a new css button like below ```json .dex-btn-icon--<your-logo_svg> {   background-image: url(../static/img/<your-logo.svg>); } ```  To use a default icon simply enter an icon name from the pre-provided defaults found in the static/img folder The default icons are   - bitbucket   - coreos   - email   - github   - gitlab   - google   - ldap   - linkedin   - microsoft   - oidc   - saml   # noqa: E501

        :return: The icon of this BaseUpstream.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this BaseUpstream.

        The icon file to be used, limited to: numbers, letters, underscores, hyphens and periods. It is part of a css class (with the periods replaced by underscores).  To use a custom icon than the provided default you will need to add the icon the static/img folder and update the static css file to add a new css button like below ```json .dex-btn-icon--<your-logo_svg> {   background-image: url(../static/img/<your-logo.svg>); } ```  To use a default icon simply enter an icon name from the pre-provided defaults found in the static/img folder The default icons are   - bitbucket   - coreos   - email   - github   - gitlab   - google   - ldap   - linkedin   - microsoft   - oidc   - saml   # noqa: E501

        :param icon: The icon of this BaseUpstream.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                icon is not None and len(icon) > 50):
            raise ValueError("Invalid value for `icon`, length must be less than or equal to `50`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                icon is not None and len(icon) < 1):
            raise ValueError("Invalid value for `icon`, length must be greater than or equal to `1`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                icon is not None and not re.search(r'^[0-9a-zA-Z-_.]+$', icon)):  # noqa: E501
            raise ValueError(r"Invalid value for `icon`, must be a follow pattern or equal to `/^[0-9a-zA-Z-_.]+$/`")  # noqa: E501

        self._icon = icon

    @property
    def auto_create_status(self):
        """Gets the auto_create_status of this BaseUpstream.  # noqa: E501


        :return: The auto_create_status of this BaseUpstream.  # noqa: E501
        :rtype: AutoCreateStatus
        """
        return self._auto_create_status

    @auto_create_status.setter
    def auto_create_status(self, auto_create_status):
        """Sets the auto_create_status of this BaseUpstream.


        :param auto_create_status: The auto_create_status of this BaseUpstream.  # noqa: E501
        :type: AutoCreateStatus
        """

        self._auto_create_status = auto_create_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BaseUpstream):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BaseUpstream):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.applications_api import ApplicationsApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestApplicationsApi(unittest.TestCase):
    """ApplicationsApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.applications_api.ApplicationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_config(self):
        """Test case for add_config

        Add an environment configuration row  # noqa: E501
        """
        pass

    def test_add_role(self):
        """Test case for add_role

        Add a role to the application.  # noqa: E501
        """
        pass

    def test_add_role_to_rule_entry(self):
        """Test case for add_role_to_rule_entry

        Add a rule to a role in the application.  # noqa: E501
        """
        pass

    def test_add_rule(self):
        """Test case for add_rule

        Add a rule to the application.  # noqa: E501
        """
        pass

    def test_create_agent(self):
        """Test case for create_agent

        Create a secure agent  # noqa: E501
        """
        pass

    def test_create_application(self):
        """Test case for create_application

        Create an application  # noqa: E501
        """
        pass

    def test_delete_agent(self):
        """Test case for delete_agent

        Delete a secure agent  # noqa: E501
        """
        pass

    def test_delete_application(self):
        """Test case for delete_application

        Remove an application  # noqa: E501
        """
        pass

    def test_delete_config(self):
        """Test case for delete_config

        Remove an environment configuration  # noqa: E501
        """
        pass

    def test_delete_role(self):
        """Test case for delete_role

        Remove a role  # noqa: E501
        """
        pass

    def test_delete_role_to_rule_entry(self):
        """Test case for delete_role_to_rule_entry

        Remove a role_to_rule_entry  # noqa: E501
        """
        pass

    def test_delete_rule(self):
        """Test case for delete_rule

        Remove a rule  # noqa: E501
        """
        pass

    def test_get_agent(self):
        """Test case for get_agent

        Get a secure agent  # noqa: E501
        """
        pass

    def test_get_application(self):
        """Test case for get_application

        Get a application  # noqa: E501
        """
        pass

    def test_get_config(self):
        """Test case for get_config

        Get environment configuration  # noqa: E501
        """
        pass

    def test_get_environment(self):
        """Test case for get_environment

        Get an environment  # noqa: E501
        """
        pass

    def test_get_role(self):
        """Test case for get_role

        Get a role  # noqa: E501
        """
        pass

    def test_get_role_to_rule_entry(self):
        """Test case for get_role_to_rule_entry

        Get a role_to_rule_entry  # noqa: E501
        """
        pass

    def test_get_rule(self):
        """Test case for get_rule

        Get a rule  # noqa: E501
        """
        pass

    def test_list_agents(self):
        """Test case for list_agents

        List secure agents  # noqa: E501
        """
        pass

    def test_list_application_summaries(self):
        """Test case for list_application_summaries

        List application summaries  # noqa: E501
        """
        pass

    def test_list_applications(self):
        """Test case for list_applications

        Get applications  # noqa: E501
        """
        pass

    def test_list_combined_rules(self):
        """Test case for list_combined_rules

        List rules combined by scope or role  # noqa: E501
        """
        pass

    def test_list_configs(self):
        """Test case for list_configs

        Get all environment configuration  # noqa: E501
        """
        pass

    def test_list_environment_configs_all_apps(self):
        """Test case for list_environment_configs_all_apps

        Get all environment configuration for a given organisation.  # noqa: E501
        """
        pass

    def test_list_role_to_rule_entries(self):
        """Test case for list_role_to_rule_entries

        Get all RoleToRuleEntries  # noqa: E501
        """
        pass

    def test_list_roles(self):
        """Test case for list_roles

        Get all roles  # noqa: E501
        """
        pass

    def test_list_rules(self):
        """Test case for list_rules

        Get all rules  # noqa: E501
        """
        pass

    def test_list_runtime_status(self):
        """Test case for list_runtime_status

        Get an environment's runtime status  # noqa: E501
        """
        pass

    def test_replace_agent(self):
        """Test case for replace_agent

        Update a secure agent  # noqa: E501
        """
        pass

    def test_replace_application(self):
        """Test case for replace_application

        Create or update an application  # noqa: E501
        """
        pass

    def test_replace_config(self):
        """Test case for replace_config

        Update environment configuration  # noqa: E501
        """
        pass

    def test_replace_environment(self):
        """Test case for replace_environment

        Update an environment  # noqa: E501
        """
        pass

    def test_replace_role(self):
        """Test case for replace_role

        Update a role  # noqa: E501
        """
        pass

    def test_replace_role_to_rule_entry(self):
        """Test case for replace_role_to_rule_entry

        Update a role_to_rule_entry  # noqa: E501
        """
        pass

    def test_replace_rule(self):
        """Test case for replace_rule

        Update a rule  # noqa: E501
        """
        pass

    def test_replace_runtime_status(self):
        """Test case for replace_runtime_status

        update an environemnt's runtime status  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class ChallengeEndpoint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'endpoint': 'str',
        'type': 'str'
    }

    attribute_map = {
        'endpoint': 'endpoint',
        'type': 'type'
    }

    def __init__(self, endpoint=None, type=None, local_vars_configuration=None):  # noqa: E501
        """ChallengeEndpoint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._endpoint = None
        self._type = None
        self.discriminator = None

        if endpoint is not None:
            self.endpoint = endpoint
        if type is not None:
            self.type = type

    @property
    def endpoint(self):
        """Gets the endpoint of this ChallengeEndpoint.  # noqa: E501

        The endpoint id. This corresponds to a configuration for the given type.  # noqa: E501

        :return: The endpoint of this ChallengeEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this ChallengeEndpoint.

        The endpoint id. This corresponds to a configuration for the given type.  # noqa: E501

        :param endpoint: The endpoint of this ChallengeEndpoint.  # noqa: E501
        :type: str
        """

        self._endpoint = endpoint

    @property
    def type(self):
        """Gets the type of this ChallengeEndpoint.  # noqa: E501

        The type of challenge to issue. This controls how the user is informed of the challenge, as well as how the challenge can be satisfied. The follow types are supported:   - sms:  a `sms` challenge informs the user via text message of the challenge. The challenge can     be answered via the link provided in the text message. The user can deny the challenge via this     mechanism as well.   - web_push: a `web_push` challenge informs the user of the challenge on every device they have   registered via the web push (rfc8030) mechanism. If the user accepts via the link provided in   the web push, the challenge will be satisfied. The user can deny the challenge via this   mechanism as well.   - totp: a time-based one-time password challenge allows the user to enter the code from their registered   - webauthn: a challenge issued for a specific device the user has possession of. Either a yubikey, or a phone that has a Trusted Platform Module.   device and application. enum: [sms, web_push, totp, webauthn] example: web_push   # noqa: E501

        :return: The type of this ChallengeEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ChallengeEndpoint.

        The type of challenge to issue. This controls how the user is informed of the challenge, as well as how the challenge can be satisfied. The follow types are supported:   - sms:  a `sms` challenge informs the user via text message of the challenge. The challenge can     be answered via the link provided in the text message. The user can deny the challenge via this     mechanism as well.   - web_push: a `web_push` challenge informs the user of the challenge on every device they have   registered via the web push (rfc8030) mechanism. If the user accepts via the link provided in   the web push, the challenge will be satisfied. The user can deny the challenge via this   mechanism as well.   - totp: a time-based one-time password challenge allows the user to enter the code from their registered   - webauthn: a challenge issued for a specific device the user has possession of. Either a yubikey, or a phone that has a Trusted Platform Module.   device and application. enum: [sms, web_push, totp, webauthn] example: web_push   # noqa: E501

        :param type: The type of this ChallengeEndpoint.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ChallengeEndpoint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ChallengeEndpoint):
            return True

        return self.to_dict() != other.to_dict()



from . import context
from .input_helpers import get_org_from_input_or_ctx
from .output.table import (
    format_table,
    metadata_column,
    spec_column,
)
import agilicus


def query_permissions(ctx, org_id=None, **kwargs):
    org_id = get_org_from_input_or_ctx(ctx, org_id=org_id)
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    query_results = apiclient.permissions_api.list_resource_permissions(
        org_id=org_id, **kwargs
    )
    if query_results:
        return query_results.resource_permissions
    return []


def format_permissions(ctx, roles):
    columns = [
        metadata_column("id"),
        spec_column("resource_type", "type"),
        spec_column("user_id", "user id"),
        spec_column("org_id", "org id"),
        spec_column("resource_id", "resource id"),
        spec_column("resource_role_name", "role"),
    ]
    return format_table(ctx, roles, columns)


def add_permission(
    ctx, user_id, resource_id, resource_type, resource_role_name, org_id=None
):
    org_id = get_org_from_input_or_ctx(ctx, org_id=org_id)
    spec = agilicus.ResourcePermissionSpec(
        org_id=org_id,
        user_id=user_id,
        resource_type=resource_type,
        resource_role_name=resource_role_name,
        resource_id=resource_id,
    )
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    return apiclient.permissions_api.create_resource_permission(
        agilicus.ResourcePermission(spec=spec)
    ).to_dict()


def delete_permission(ctx, id, org_id=None):
    org_id = get_org_from_input_or_ctx(ctx, org_id=org_id)
    token = context.get_token(ctx)
    apiclient = context.get_apiclient(ctx, token)

    return apiclient.permissions_api.delete_resource_permission(id, org_id=org_id)



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.organisations_api import OrganisationsApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestOrganisationsApi(unittest.TestCase):
    """OrganisationsApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.organisations_api.OrganisationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_blocking_upgrade_orgs_task(self):
        """Test case for create_blocking_upgrade_orgs_task

        utility to upgrade organisations  # noqa: E501
        """
        pass

    def test_create_org(self):
        """Test case for create_org

        Create an organisation  # noqa: E501
        """
        pass

    def test_create_sub_org(self):
        """Test case for create_sub_org

        Create a sub organisation  # noqa: E501
        """
        pass

    def test_delete_sub_org(self):
        """Test case for delete_sub_org

        Delete a sub organisation  # noqa: E501
        """
        pass

    def test_get_org(self):
        """Test case for get_org

        Get a single organisation  # noqa: E501
        """
        pass

    def test_get_org_status(self):
        """Test case for get_org_status

        Get the status of an organisation  # noqa: E501
        """
        pass

    def test_list_orgs(self):
        """Test case for list_orgs

        Get all organisations  # noqa: E501
        """
        pass

    def test_list_sub_orgs(self):
        """Test case for list_sub_orgs

        Get all sub organisations  # noqa: E501
        """
        pass

    def test_replace_org(self):
        """Test case for replace_org

        Create or update an organisation  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.connectors_api import ConnectorsApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestConnectorsApi(unittest.TestCase):
    """ConnectorsApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.connectors_api.ConnectorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_agent_connector(self):
        """Test case for create_agent_connector

        Create an agent connector  # noqa: E501
        """
        pass

    def test_create_agent_csr(self):
        """Test case for create_agent_csr

        Creates a CertSigningReq  # noqa: E501
        """
        pass

    def test_create_agent_stats(self):
        """Test case for create_agent_stats

        Creates an AgentConnectorStats record.  # noqa: E501
        """
        pass

    def test_create_csr(self):
        """Test case for create_csr

        Creates a CertSigningReq  # noqa: E501
        """
        pass

    def test_create_ipsec_connector(self):
        """Test case for create_ipsec_connector

        Create an IPsec connector  # noqa: E501
        """
        pass

    def test_delete_agent_connector(self):
        """Test case for delete_agent_connector

        Delete a agent  # noqa: E501
        """
        pass

    def test_delete_connector(self):
        """Test case for delete_connector

        Delete a connector  # noqa: E501
        """
        pass

    def test_delete_ipsec_connector(self):
        """Test case for delete_ipsec_connector

        Delete an IPsec connector  # noqa: E501
        """
        pass

    def test_get_agent_connector(self):
        """Test case for get_agent_connector

        Get an agent  # noqa: E501
        """
        pass

    def test_get_agent_csr(self):
        """Test case for get_agent_csr

        Update a CertSigningReq  # noqa: E501
        """
        pass

    def test_get_agent_info(self):
        """Test case for get_agent_info

        Get information associated with connector  # noqa: E501
        """
        pass

    def test_get_agent_stats(self):
        """Test case for get_agent_stats

        Get the AgentConnector stats  # noqa: E501
        """
        pass

    def test_get_connector(self):
        """Test case for get_connector

        Get a connector  # noqa: E501
        """
        pass

    def test_get_ipsec_connector(self):
        """Test case for get_ipsec_connector

        Get an IPsec connector  # noqa: E501
        """
        pass

    def test_get_ipsec_connector_info(self):
        """Test case for get_ipsec_connector_info

        Get IPsec connector runtime information  # noqa: E501
        """
        pass

    def test_list_agent_connector(self):
        """Test case for list_agent_connector

        list agent connectors  # noqa: E501
        """
        pass

    def test_list_agent_csr(self):
        """Test case for list_agent_csr

        list agent connector certificate signing requests  # noqa: E501
        """
        pass

    def test_list_connector(self):
        """Test case for list_connector

        List connectors  # noqa: E501
        """
        pass

    def test_list_ipsec_connector(self):
        """Test case for list_ipsec_connector

        list IPsec connectors  # noqa: E501
        """
        pass

    def test_replace_agent_connector(self):
        """Test case for replace_agent_connector

        Update an agent  # noqa: E501
        """
        pass

    def test_replace_agent_connector_local_auth_info(self):
        """Test case for replace_agent_connector_local_auth_info

        Update an agent's local authentication information  # noqa: E501
        """
        pass

    def test_replace_agent_csr(self):
        """Test case for replace_agent_csr

        Update a CertSigningReq  # noqa: E501
        """
        pass

    def test_replace_ipsec_connector(self):
        """Test case for replace_ipsec_connector

        Update an IPsec connector  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.service_forwarder_status import ServiceForwarderStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestServiceForwarderStatus(unittest.TestCase):
    """ServiceForwarderStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ServiceForwarderStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.service_forwarder_status.ServiceForwarderStatus()  # noqa: E501
        if include_optional :
            return ServiceForwarderStatus(
                connection_uri = '0', 
                application_service = agilicus_api.models.application_service.ApplicationService(
                    created = '2015-07-07T15:49:51.230+02:00', 
                    id = '123', 
                    name = '0', 
                    org_id = '0', 
                    hostname = 'db.example.com', 
                    ipv4_addresses = [
                        '192.0.2.1'
                        ], 
                    name_resolution = 'static', 
                    port = 56, 
                    protocol = 'tcp', 
                    assignments = [
                        agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                            app_id = '0', 
                            environment_name = '0', 
                            org_id = '0', )
                        ], 
                    updated = '2015-07-07T15:49:51.230+02:00', 
                    service_type = 'vpn', 
                    service_protocol_type = 'ip', 
                    tls_enabled = True, 
                    tls_verify = True, 
                    connector_id = '123', 
                    connection_uri = '0', )
            )
        else :
            return ServiceForwarderStatus(
        )

    def testServiceForwarderStatus(self):
        """Test ServiceForwarderStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_proxy_stats import AgentConnectorProxyStats  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorProxyStats(unittest.TestCase):
    """AgentConnectorProxyStats unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorProxyStats
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_proxy_stats.AgentConnectorProxyStats()  # noqa: E501
        if include_optional :
            return AgentConnectorProxyStats(
                overview = agilicus_api.models.agent_connector_proxy_request_stats.AgentConnectorProxyRequestStats(
                    last_request_start_time = '2020-07-07T15:49:51.230Z', 
                    bytes_received = 0, 
                    bytes_sent = 0, 
                    requests = agilicus_api.models.agent_connector_proxy_request_stats_details.AgentConnectorProxyRequestStatsDetails(
                        started = 0, 
                        finished = 0, 
                        status_1xx = 0, 
                        status_2xx = 0, 
                        status_3xx = 0, 
                        status_4xx = 0, 
                        status_5xx = 0, 
                        status_unknown = 0, 
                        failed_authentication = 0, 
                        failed_authorisation = 0, ), ), 
                start_time = '2020-07-07T15:49:51.230Z', 
                stop_time = '2020-07-07T15:49:51.230Z'
            )
        else :
            return AgentConnectorProxyStats(
                overview = agilicus_api.models.agent_connector_proxy_request_stats.AgentConnectorProxyRequestStats(
                    last_request_start_time = '2020-07-07T15:49:51.230Z', 
                    bytes_received = 0, 
                    bytes_sent = 0, 
                    requests = agilicus_api.models.agent_connector_proxy_request_stats_details.AgentConnectorProxyRequestStatsDetails(
                        started = 0, 
                        finished = 0, 
                        status_1xx = 0, 
                        status_2xx = 0, 
                        status_3xx = 0, 
                        status_4xx = 0, 
                        status_5xx = 0, 
                        status_unknown = 0, 
                        failed_authentication = 0, 
                        failed_authorisation = 0, ), ),
        )

    def testAgentConnectorProxyStats(self):
        """Test AgentConnectorProxyStats"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.04.01
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.mfa_enrollment_question import MFAEnrollmentQuestion  # noqa: E501
from agilicus_api.rest import ApiException

class TestMFAEnrollmentQuestion(unittest.TestCase):
    """MFAEnrollmentQuestion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MFAEnrollmentQuestion
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.mfa_enrollment_question.MFAEnrollmentQuestion()  # noqa: E501
        if include_optional :
            return MFAEnrollmentQuestion(
                input = agilicus_api.models.mfa_enrollment_question_input.MFAEnrollmentQuestionInput(
                    login_info = agilicus_api.models.mfa_enrollment_question_login_info.MFAEnrollmentQuestionLoginInfo(
                        issuer_org_id = 'absjfladasdf23', 
                        enrollment_expiry = '2015-07-07T15:49:51.230+02:00', 
                        user_mfa_methods = ["totp","webauthn"], ), )
            )
        else :
            return MFAEnrollmentQuestion(
                input = agilicus_api.models.mfa_enrollment_question_input.MFAEnrollmentQuestionInput(
                    login_info = agilicus_api.models.mfa_enrollment_question_login_info.MFAEnrollmentQuestionLoginInfo(
                        issuer_org_id = 'absjfladasdf23', 
                        enrollment_expiry = '2015-07-07T15:49:51.230+02:00', 
                        user_mfa_methods = ["totp","webauthn"], ), ),
        )

    def testMFAEnrollmentQuestion(self):
        """Test MFAEnrollmentQuestion"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
